pkgsrc/mail/spamassassin/patches/patch-ad
heinz a415440a32 Updated to version 3.1.0.
Pkgsrc changes:
  - p5-Storable is no longer a necessary.
  - Let DragonFlyBSD also use the rc.d script (patch-ad).
  - Sa-update needs p5-libwww (for LWP::UserAgent, HTTP::Date),
    p5-Archive-Tar and p5-IO-Zlib.
  - Many of the plugins are available as pkgsrc packages (p5-Mail-SPF-Query,
    p5-IP-Country, p5-Net-Ident, ...) but are not required.
  - Renamed some options to follow the naming conventions described in the
    pkgsrc guide.
  - Removed patch-ax again; it is already incorporated in 3.1.0.

  - Reworked DESCR to use less than 25 lines.
  - Removed SPAMASSASSIN_VERSION for clarity of DISTNAME and PKGNAME.
  - Prepended variables internal to the package with an underscore.
  - Rearranged MAKE_PARAMS alphabetically.
  - Simplified some internal variables (concatenation instead of
    substitution: _EGDIR, _DOCDIR,...)
  - Loop variables use all lower-case now.
  - Added a rule to lower score for mail from pkgsrc-bugs in netbsd_lists.cf.
  - The test t/spf.t (fails for SPF_HELO_*) has a know problem (SA Bug 4685).

Relevant changes since version 3.0.4:
=====================================
- Apache preforking algorithm adopted; number of spamd child processes is now
  scaled, according to demand.  This provides better VM behaviour when not
  under peak load.

- Inclusion of sa-update script which will allow for updates of rules and
  scores in between code releases.

- added PostgreSQL, MySQL 4.1+, and local SDBM file Bayes storage modules. SQL
  storage is now recommended for Bayes, instead of DB_File. NDBM_File support
  has been dropped due to a major bug in that module.

- detect legitimate SMTP AUTH submission, to avoid false positives on
  Dynablock-style rules.

- new Advance Fee Fraud (419 scam) rules.

- removed use of the Storable module, due to several reported hangs on SMP
  Linux machines.

- Converted several rule/engine components into Plugins such as:
  AccessDB, AWL, Pyzor, Razor2, DCC, Bayes AutoLearn Determination, etc.

- new plugins: DomainKeys (off by default), MIMEHeader: a new plugin to perform
  tests against header in internal MIME structure, ReplaceTags: plugin by Felix
  Bauer to support fuzzy text matching, WhiteListSubject: plugin added to
  support user whitelists by Subject header.

- TextCat language guesser moved to a plugin.  (This means "ok_languages"
  is no longer part of the core engine by default.)

- Razor: disable Razor2 support by default per our policy, since the
  service is not free for non-personal use.  It's trivial to reenable.

- DCC: disable DCC for similar reasons, due to new license terms.

- Net::DNS bug: high load caused answer packets to be mixed up and delivered as
  answers to the wrong request, causing false positives.  worked around.

- DNSBL lookups and other DNS operations are now more efficient, by using a
  custom single-socket event-based model instead of Net::DNS.

- add support for accreditation services, including Habeas v2.

- better URI parsing -- many evasion tricks now caught.

- URIBL lookups are prioritized based on the location in the message
  the URI was found.

- mass-check now supports reusing realtime DNSBL hit results, and sample-based
  Bayes autolearning emulation, to reduce complexity.

- sa-learn, spamassassin and mass-check now have optional progress bars.

- modify header ordering for DomainKeys compatibility, by placing markup
  headers at the top of the message instead at the bottom of the list.

- spamd/spamc now support remote Bayes training, and reporting spam.

- spamc now supports reading its flags from a configuration file using the -F
  switch, contributed by John Madden.

- added SPF-based whitelisting.

- Polish rules contributed by Radoslaw Stachowiak.

- many rule changes and additions.
2005-11-13 22:48:32 +00:00

55 lines
1.7 KiB
Text

$NetBSD: patch-ad,v 1.7 2005/11/13 22:48:32 heinz Exp $
--- spamd/netbsd-rc-script.sh.orig Sat Oct 23 01:39:18 2004
+++ spamd/netbsd-rc-script.sh
@@ -9,7 +9,7 @@
# @PREFIX@/share/doc/spamassassin/spamd/README.spamd
# especially the section about security.
-## only for NetBSD
+## only for DragonFlyBSD/NetBSD
# PROVIDE: spamd
# REQUIRE: LOGIN
# BEFORE: mail
@@ -34,15 +34,17 @@ command_args="-d -r ${pidfile}"
extra_commands="reload"
sig_reload="HUP"
# default values, may be overridden on NetBSD by setting them in /etc/rc.conf
spamd_flags=${spamd_flags-"-H -c"}
spamd=${spamd:-NO}
spamd_fdlimit=${spamd_fdlimit-"128"}
-OPSYS=@OPSYS@ # set during package build
-INTERPRETER_SUPPORT=@INTERPRETER_SUPPORT@ # set during package build
+# both set during package build
+OPSYS=@OPSYS@
+_INTERPRETER_SUPPORT=@_INTERPRETER_SUPPORT@
-# A default limit of 64 (at least on NetBSD) may be too low for many
+# A default limit of 64 on NetBSD may be too low for many
# people (eg with addional RBL rules)
SOFT_FDLIMIT=`ulimit -S -n`
HARD_FDLIMIT=`ulimit -H -n`
@@ -96,8 +98,8 @@ spamd_reload()
kill -${sig_reload} ${the_spamd_pid}
}
-if [ "${OPSYS}" = "NetBSD" ]; then
- if checkyesno INTERPRETER_SUPPORT; then
+if [ "${OPSYS}" = "NetBSD" -o "${OPSYS}" = "DragonFly" ]; then
+ if checkyesno _INTERPRETER_SUPPORT; then
: # support for 'command_interpreter' was added in NetBSD 1.6
else
start_cmd="spamd_start"
@@ -110,7 +112,7 @@ if [ "${OPSYS}" = "NetBSD" ]; then
load_rc_config $name
run_rc_command "$1"
-else # not NetBSD
+else # not NetBSD or DragonFlyBSD
if [ -f ${pidfile} ]; then
the_spamd_pid=`head -1 ${pidfile}`
@@ -34,15 +34,17 @@ command_args="-d -r ${pidfile}"
extra_commands="reload"
sig_reload="HUP"
-# default values, may be overridden on NetBSD by setting them in /etc/rc.conf
+# default values, may be overridden on NetBSD/DragonFlyBSD by setting them
+# in /etc/rc.conf
spamd_flags=${spamd_flags-"-H -c"}
spamd=${spamd:-NO}